@@ -1,43 +1,38 @@
 /*
     Copyright 2013 by Reza Fatahilah Shah <rshah0385@kireihana.com>
- 
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "advancedconfig.h"
+#include "config.h"
 #include "sddmkcm.h"
+#include "themeconfig.h"
 
 #include <algorithm>
 
+#include <QDebug>
 #include <QDir>
 #include <QHBoxLayout>
 #include <QTabWidget>
 
-#include <KPluginFactory>
-
-#include <KAuth/KAuthActionReply>
-
 #include <KAboutData>
-
+#include <KAuth/KAuthActionReply>
+#include <kauthexecutejob.h>
 #include <KLocalizedString>
-#include <QDebug>
-
-#include "config.h"
-#include "themeconfig.h"
-#include "advanceconfig.h"
-
+#include <KPluginFactory>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
-#include <kauthexecutejob.h>
 
 K_PLUGIN_FACTORY(SddmKcmFactory, registerPlugin<SddmKcm>();)
 
@@ -59,6 +54,8 @@ SddmKcm::SddmKcm(QWidget *parent, const QVariantList &args) :
 
     mSddmConfig = KSharedConfig::openConfig(QStringLiteral(SDDM_CONFIG_FILE), KConfig::CascadeConfig);
 
+    mSddmOldConfig = KSharedConfig::openConfig(QStringLiteral("sddm.conf"), KConfig::CascadeConfig);
+
     // This does not listen for new config files in the directory.
     QStringList configFiles = QDir(QLatin1String(SDDM_CONFIG_DIR)).entryList(QDir::Files | QDir::NoDotAndDotDot, QDir::LocaleAware),
                 systemConfigFiles = QDir(QLatin1String(SDDM_SYSTEM_CONFIG_DIR)).entryList(QDir::Files | QDir::NoDotAndDotDot, QDir::LocaleAware);
@@ -70,6 +67,7 @@ SddmKcm::SddmKcm(QWidget *parent, const QVariantList &args) :
                     [](const QString &filename) -> QString { return QStringLiteral(SDDM_CONFIG_DIR "/") + filename; });
 
     mSddmConfig->addConfigSources(systemConfigFiles + configFiles);
+    mSddmOldConfig->addConfigSources(systemConfigFiles + configFiles);
 
     prepareUi();
 }
@@ -81,7 +79,8 @@ SddmKcm::~SddmKcm()
 void SddmKcm::save()
 {
     QVariantMap args;
-    
+
+    args[QStringLiteral("kde_settings.conf")] = QString {QLatin1String(SDDM_CONFIG_DIR "/") + QStringLiteral("kde_settings.conf")};
     args[QStringLiteral("sddm.conf")] = QLatin1String(SDDM_CONFIG_FILE);
 
     if (!mThemeConfig->themeConfigPath().isEmpty()) {
@@ -90,13 +89,13 @@ void SddmKcm::save()
 
     qDebug() << "Ovr:" << args[QStringLiteral("theme.conf.user")].toString();
     args.unite(mThemeConfig->save());
-    args.unite(mAdvanceConfig->save());
+    args.unite(mAdvancedConfig->save());
 
     KAuth::Action saveAction = authAction();
 
     saveAction.setHelperId(QStringLiteral("org.kde.kcontrol.kcmsddm"));
     saveAction.setArguments(args);
-    
+
     auto job = saveAction.execute();
     job->exec();
 
@@ -108,7 +107,7 @@ void SddmKcm::save()
         changed(false);
         qDebug() << "Option saved";
     }
-    
+
 }
 
 void SddmKcm::prepareUi()
@@ -116,16 +115,16 @@ void SddmKcm::prepareUi()
     QHBoxLayout* layout = new QHBoxLayout(this);
     QTabWidget* tabHolder = new QTabWidget(this);
     layout->addWidget(tabHolder);
-    
+
     mThemeConfig = new ThemeConfig(mSddmConfig, this);
     connect(mThemeConfig, SIGNAL(changed(bool)), SIGNAL(changed(bool)));
-    
+
     tabHolder->addTab(mThemeConfig, i18n("Theme"));
-    
-    mAdvanceConfig = new AdvanceConfig(mSddmConfig, this);
-    connect(mAdvanceConfig, SIGNAL(changed(bool)), SIGNAL(changed(bool)));
-    
-    tabHolder->addTab(mAdvanceConfig, i18n("Advanced"));
+
+    mAdvancedConfig = new AdvancedConfig(mSddmConfig, this);
+    connect(mAdvancedConfig, SIGNAL(changed(bool)), SIGNAL(changed(bool)));
+
+    tabHolder->addTab(mAdvancedConfig, i18n("Advanced"));
 }
 
 #include "sddmkcm.moc"
